const webpack = require('webpack');
const merge = require('webpack-merge');
const path = require('path');
const TerserPlugin = require('terser-webpack-plugin');


const commonConfig = {
  output: {
    path: path.resolve(__dirname + '/dist/plugins/'),
    // filename: 'm16y-plugin.js'
  },
  module: {
    rules: [
      {
        test: /\.js$/,
        include: path.join(__dirname, '..'),
        use: {
          loader: 'babel-loader',
          options: {
            presets: ['@babel/preset-env'],
            plugins: ['@babel/plugin-proposal-object-rest-spread']
          },
        },
        exclude: /node_modules/,
        // query: {
        //   presets:[ 'es2015', 'stage-2' ]
        // }
      },
      {
        test: /\.vue$/,
        use: {
          loader: 'vue-loader'
        }
      },
      {
        test: /\.css$/,
        use: {
          loader: 'style!less!css',
        }
      },
    ],
  },
  // plugins: [
  //   new webpack.optimize.UglifyJsPlugin( {
  //     minimize : true,
  //     sourceMap : false,
  //     mangle: true,
  //     compress: {
  //       warnings: false
  //     },
  //   }),
  // ],
  optimization: {
    minimizer: [
      new TerserPlugin({
        cache: true,
        parallel: true,
        sourceMap: true, // Must be set to true if using source-maps in production
      }),
    ]
  }
};

module.exports = [
  merge(commonConfig, {
    entry: path.join(__dirname, '../index.js'),
    output: {
      filename: 'vue-m16y-plugin',
      libraryTarget: 'window',
      library: 'M16yPlugin',
    },
  }),
  merge(commonConfig, {
    entry: path.join(__dirname, '../index.js'),
    output: {
      filename: 'vue-m16y-plugin',
      libraryTarget: 'umd',
      library: 'vue-m16y-plugin',
      umdNamedDefine: true,
    }
  }),
];